# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Decode uu/xx/b64/mime/yenc/etc.-encoded data
Name:		perl-Convert-UUlib
Epoch:		4
Version:	1.8
Release:	7.%{__distinit}%{__distvers}
# uulib/ecb.h: BSD-2-Clause OR GPL-2.0-or-later
# uulib/crc32.c: some unrecognized 3-clause BSD variant
# uulib: GPL-2.0-or-later
# Perl interface: GPL-1.0-or-later OR Artistic-1.0-Perl
License:	(BSD-2-Clause OR GPL-2.0-or-later) AND BSD-3-Clause AND (GPL-1.0-or-later OR Artistic-1.0-Perl) AND GPL-2.0-or-later
URL:		https://metacpan.org/release/Convert-UUlib
Source0:	https://cpan.metacpan.org/modules/by-module/Convert/Convert-UUlib-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Canary::Stability)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(common::sense) >= 3.74
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
# Test Suite
# (none)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
This module started as an interface to the uulib/uudeview library by Frank
Pilhofer that can be used to decode all kinds of usenet (and other) binary
messages.

After upstream abandoned the project, the library was continuously bug-fixed
and improved in this module, with major focuses on security fixes, correctness
and speed (that does not mean that this library is considered safe with
untrusted data, but it is surely safer than the original uudeview).

%prep
%setup -q -n Convert-UUlib-%{version} 

%build
PERL_CANARY_STABILITY_NOPROMPT=1 perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}
 
%check
make test

%files
%license COPYING*
%doc README* Changes doc/* example-decoder
%{perl_vendorarch}/Convert/
%{perl_vendorarch}/auto/Convert/
%{_mandir}/man3/Convert::UUlib.3*

%changelog
* Tue Jul 11 2023 Paul Howarth <paul@city-fan.org> - 4:1.8-7
- Perl 5.38 rebuild

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 4:1.8-6
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 4:1.8-2
- Perl 5.34 rebuild

* Mon Dec 21 2020 Paul Howarth <paul@city-fan.org> - 4:1.8-1
- Update to 1.8
  - No bugfixes in this release due to lack of known bugs, but the major
    changes in this release might have introduced new bugs, so watch out
  - Update large decoder example to disable OPT_AUTOCHK and use Smerge -1
  - Some micro-optimizations
    - Avoid costly string comparisons by comparing hashes when inserting items,
      which speeds up insertion by a constant factor
    - Improve uulist (and other) structure layout and size
    - Reverse the order of file list items, which heuristically improves match
      speed with large usenet file lists
    - Use getc instead of fgetc, which makes no difference on gnu/linux
    - Clean up _FP symbol names not to start with an underscore
    - Use feof_unlocked and ferror_unlocked
    - Implement a faster ASCII-only strnicmp
  - Miscellaneous very minor code improvements
    - Remove quite a bit of pre-posix/dos/etc. cruft
    - Use flockfile, if available, for a potential but small speed gain
    - Speed up inner yenc decoder loop
    - Kentnl said that this module should no longer claim to be a simple
      interface to uulib, as the bundled copy is now better maintained than
      the original upstream library
- Update summary and description as per upstream

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 3:1.71-2
- Perl 5.32 rebuild

* Tue Mar 17 2020 Paul Howarth <paul@city-fan.org> - 3:1.71-1
- Update to 1.71
  - Backport to c89

* Mon Mar  2 2020 Paul Howarth <paul@city-fan.org> - 3:1.7-1
- Update to 1.7
  - New function: GetFileList
  - Experimental perlmulticore support (see manpage)
  - Initialize is now a NOP and CleanUp automatically initializes again
  - Updated example decoder and documentation a bit
  - Include ecb.h to deal with compiler built-ins and endianness
  - Some further micro-optimizations in hot code, especially for yEnc
  - Replace crc32 function by slice-by-16 version by Stephan Brumme, which
    should speed up yEnc en-/decoding
  - yEnc: Do not calculate two CRCs per part: instead, combine the part CRCs
    together to form the file CRC
  - yEnc: Allow pcrc= in addition to pcrc32= for yenc trailers, as some draft
    mentions both and it is actually in active use
  - yEnc: Ignore crc32= on multiparts, except on the last part, which avoids
    spurious corruption warnings
  - Be more precise in documenting code licenses in COPYING
  - Convert constant creation to the method I normally use
  - Use common::sense
- Add patch to support building with older compilers that don't support C99

* Tue Feb 18 2020 Paul Howarth <paul@city-fan.org> - 2:1.62-1
- Update to 1.62
  - Major performance improvement by simplifying code in _FP_gets to not use
    fscanf; this might slow things down on platforms with very slow fgetc
  - Lint uulib: fix some format string type mismatches and some other minor
    issues

* Fri Oct 25 2019 Paul Howarth <paul@city-fan.org> - 2:1.6-1
- Update to 1.6
  - Fix heap overflow (https://bugzilla.redhat.com/show_bug.cgi?id=1711098);
    the defense-in-depth mechanism based on mmap should make this unexploitable
    for other than denial of service, on systems supporting mmap/mprotect

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 2:1.5-13
- Perl 5.30 rebuild
- Bump epoch as per Fedora package

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1.50-4
- Perl 5.28 rebuild

* Wed Mar 28 2018 Paul Howarth <paul@city-fan.org> - 1.50-3
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Thu Aug 11 2016 Paul Howarth <paul@city-fan.org> - 1.50-2
- BR: perl-devel and perl-generators where available
- Simplify find commands using -empty and -delete

* Sun Jul 12 2015 Paul Howarth <paul@city-fan.org> - 1.50-1
- Update to 1.50
  - Fix a heap overflow
  - On systems that support it (POSIX + mmap + map_anonymous), allocate all
    dynamic areas via mmap and put four guard pages around them, to catch
    similar heap overflows safely in the future
  - Find a safer way to pass in CC/CFLAGS to uulib
  - Added stability canary support
- Classify buildreqs by usage
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Thu Jun  7 2012 Paul Howarth <paul@city-fan.org> - 1.40-3
- BR: perl(Carp) and perl(Exporter)
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 1.40-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sun May 29 2011 Paul Howarth <paul@city-fan.org> - 1.40-1
- Update to 1.4
  - Avoid a classical buffer overflow in case a progress message is too long
  - This release adds dependencies for snprintf/vsnprintf
  - Some uuencode encoders do not generate a final "space" line before the
    "end" marker, so do not rely on the line to be there
- Nobody else likes macros for commands

* Wed Dec 15 2010 Paul Howarth <paul@city-fan.org> - 1.34-1
- Update to 1.34
  - Fix a one-byte-past-end-write buffer overflow in UURepairData
  - Quoted-printable decoding was completely broken; try a fix

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.33-4
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 1.33-3
- Fix dist tag for RHEL-6 Beta

* Thu Feb 25 2010 Paul Howarth <paul@city-fan.org> - 1.33-2
- Dist tag for Rawhide no longer needs special-casing

* Wed Oct 28 2009 Paul Howarth <paul@city-fan.org> - 1.33-1
- Update to 1.33 (handle yEnc files with part end=0 and total= more gracefully)

* Thu Sep 17 2009 Paul Howarth <paul@city-fan.org> - 1.32-1
- Update to 1.32 (exec permission on configure script fixed)

* Wed Sep 16 2009 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31
  - system versions of case-insensitive string functions not used
- Use %%{?perl_default_filter} for perl shared objects
- Fix missing exec permission on configure script

* Tue Sep  1 2009 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.3 (RPM package version 1.30 to avoid epoch bump)
  - Multiple performance improvements

* Fri Aug 28 2009 Paul Howarth <paul@city-fan.org> - 1.12-3
- Improve requires/provides filter to not filter out more than necessary

* Sun Mar  1 2009 Paul Howarth <paul@city-fan.org> - 1.12-2
- Filter out unwanted provides for perl shared objects
- Update to SLES-compatible dist tag macros

* Mon Oct 13 2008 Paul Howarth <paul@city-fan.org> - 1.12-1
- Update to 1.12

* Fri Jun 13 2008 Paul Howarth <paul@city-fan.org> - 1.11-1
- Update to 1.11
- Clarify license as GPL version 2 or later (from uulib)

* Thu May 31 2007 Paul Howarth <paul@city-fan.org> - 1.09-1
- Update to 1.09
- BuildRequire perl(ExtUtils::MakeMaker)

* Mon Dec 18 2006 Paul Howarth <paul@city-fan.org> - 1.08-1
- Update to 1.08

* Mon Dec 11 2006 Paul Howarth <paul@city-fan.org> - 1.07-1
- Update to 1.07
- Fix dist tag for development builds
- Fix argument order for find with -depth

* Thu Aug 31 2006 Paul Howarth <paul@city-fan.org> - 1.06-2
- Disregard distribution sub-release number in dist tag
- Define %%{__id_u} in a more portable way

* Tue Dec  6 2005 Paul Howarth <paul@city-fan.org> - 1.06-1
- Update to 1.06
- Simplify distribution-detection
- Remove macros %%__perl_package and %%perl_version
- Use search.cpan.org URLs
- Add example-decoder as %%doc
- Simplify compiler optimization flag settings
- Remove buildroot unconditionally in %%clean and %%install
- Don't use macros in paths for build-time commands, hardcode them instead

* Thu Jul  7 2005 Paul Howarth <paul@city-fan.org> - 1.051-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Add doc/*

* Wed Mar  9 2005 Paul Howarth <paul@city-fan.org> - 1.051-1
- Update to 1.051
- Update URL

* Wed Feb  9 2005 Paul Howarth <paul@city-fan.org> - 1.04-1
- Update to 1.04

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org> - 1.03-1
- Update to 1.03
- Tidy up spec file

* Thu Apr 15 2004 Paul Howarth <paul@city-fan.org> 1.0-3
- Added explicit perl dependency to ensure that an RPM built on a
  system with an updated version of perl (and hence having files
  installed in a place that a non-updated system won't find them)
  will not install on the non-updated system. In such cases, just
  rebuild from the source RPM
- Changed distribution-identifying macros for greater portability

* Mon Feb 16 2004 Paul Howarth <paul@city-fan.org> - 1.0-2
- Unified spec file for Red Hat and Fedora Core

* Tue Feb 03 2004 Paul Howarth <paul@city-fan.org> - 1.0-1.fc1
- Initial RPM build
